@@ -3,14 +3,12 @@ try:
 except ImportError:
     pass
 from typing import Literal
-import platform
 import tkinter as tk
 import tkinter.ttk as ttk
 import tkinter.tix as tix
 from tkdev.devresize import DevResize
 from tkdev.devicon import Icon_Empty
-from ctypes import windll, Structure, c_int, c_size_t, POINTER, sizeof
-from ctypes.wintypes import BOOL, CHAR, COLORREF, UINT
+from ctypes import windll
 from os import environ
 from enum import Enum
 try:
@@ -25,10 +23,6 @@ try:
     import win32mica as mc
 except ImportError:
     pass
-try:
-    from BlurWindow.blurWindow import GlobalBlur
-except ImportError:
-    pass
 try:
     import darkdetect
 except ImportError:
@@ -49,6 +43,24 @@ Dark = "dark"
 DWMWA_USE_IMMERSIVE_DARK_MODE = 20
 
 
+def Install(Library, Basic=True):
+    import os, sys
+    if Basic:
+        print(f"{sys.executable} -m pip install {Library} -i https://pypi.tuna.tsinghua.edu.cn/simple/")
+        os.system(f"{sys.executable} -m pip install {Library}  -i https://pypi.tuna.tsinghua.edu.cn/simple/")
+    else:
+        print(f"{sys.executable} -m pip install {Library}")
+        os.system(f"{sys.executable} -m pip install {Library}")
+
+
+def Install_ALL():
+    Install("tkinter-tooltip")
+    Install("pywin32")
+    Install("win32mica")
+    Install("BlurWindow")
+    Install("darkdetect")
+
+
 class DWMWINDOWATTRIBUTE(Enum):
     DWMWA_NCRENDERING_ENABLED = 1
     DWMWA_NCRENDERING_POLICY = 2
@@ -76,14 +88,6 @@ class DWMWINDOWATTRIBUTE(Enum):
     DWMWA_LAST = 24
 
 
-class DWM_SYSTEMBACKDROP_TYPE(Structure):
-    _fields_ = [
-        ("Attribute", c_int),
-        ("Data", POINTER(c_int)),
-        ("SizeOfData", c_size_t)
-    ]
-
-
 def dwm_set_window_attribute(window: tk.Tk, attribute, value):
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), attribute, value)
 
@@ -97,7 +101,8 @@ def window_light(window: tk.Tk):
 
 
 def window_acrylic(window: tk.Tk, Dark=False):
-    GlobalBlur(GetParent(window.winfo_id()), Dark=True)
+    from BlurWindow.blurWindow import GlobalBlur
+    GlobalBlur(GetParent(window.winfo_id()), Acrylic=True, Dark=True, QWidget=window.winfo_id)
 
 
 def window_long(window: tk.Tk, long):
@@ -819,7 +824,9 @@ class DevWindow(tk.Tk):
         self.geometry("630x300")
         self.iconbitmap(Icon_Empty)
 
-    def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto):
+    def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto, mica: bool = True):
+        if mica:
+            self.mica(mode)
         if mode == "auto":
             if darkdetect.isLight():
                 window_acrylic(self, Dark=False)
@@ -831,7 +838,10 @@ class DevWindow(tk.Tk):
             window_acrylic(self, Dark=True)
         self.update()
 
+    acrylic = wm_acrylic
+
     def wm_mica(self, mode: Literal["auto", "light", "dark"] = Auto, all: bool = False):
+        import platform
         if platform.system() == "Windows":
             if all:
                 self.configure(background=self.cget("background"))
@@ -916,4 +926,5 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 if __name__ == '__main__':
     Root = DevWindow()
+    Root.acrylic(mode=Light, mica=False)
     Root.run()
